fedex.services.ship_service.FedexDeleteShipmentRequest

Package fedex :: Package services :: Module ship_service :: Class FedexDeleteShipmentRequest |
[hide private]
[frames] | no frames]

# Class FedexDeleteShipmentRequest

source code

This class allows you to delete a shipment, given a tracking number.

Instance Methods | [hide private]
__init__(self, config_obj, *args, **kwargs) Deletes a shipment via a tracking number. | source code
_prepare_wsdl_objects(self) Preps the WSDL data structures for the user. | source code
_assemble_and_send_request(self) Fires off the Fedex request. | source code
Inherited from `base_service.FedexBaseService`: `create_wsdl_object_of_type`, `send_request` Inherited from `base_service.FedexBaseService` (private): `_check_response_for_request_errors` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Instance Variables | [hide private]
| DeletionControlType Holds the DeletrionControlType WSDL object.
| TrackingId Holds the TrackingId WSDL object.
Inherited from `base_service.FedexBaseService`: `ClientDetail`, `TransactionDetail`, `VersionId`, `WebAuthenticationDetail`, `config_obj`, `logger`, `response`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, config_obj, *args, **kwargs) (Constructor) | source code
Deletes a shipment via a tracking number. Parameters: `customer_transaction_id` - A user-specified identifier to differentiate this transaction from others. This value will be returned with the response from Fedex. Overrides: object.__init__

### _assemble_and_send_request(self) | source code
Fires off the Fedex request. Warning: NEVER CALL THIS METHOD DIRECTLY. CALL send_request(), WHICH RESIDES ON FedexBaseService AND IS INHERITED.